Fast, simple library in Go to fetch CVEs from the NVD (U.S. National Vulnerability Database) feeds.
Install
go get codeberg.org/Magnetic_Gopher/go-nvd
Usage
The go-nvd package is currently unfinished, However basics methods have been implemented for the cve package.
package main
import (
"fmt"
"codeberg.org/Magnetic_Gopher/go-nvd/cve"
)
func main() {
client := cve.NewClient(cve.ClientOptions{})
cve, err := client.FetchCVE("CVE-2026-31431")
if err != nil {
log.Fatal(err)
}
fmt.Println(cve)
}
License
All Code in this repository is licensed under the MPL